OC.L10N.register(
    "settings",
    {
    "Private" : "Kişisel",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Yalnızca mobil aygıt üzerinde Talk telefon numarası bütünleştirmesi ile eşleşen kişiler görebilir",
    "Local" : "Yerel",
    "Only visible to people on this instance and guests" : "Yalnızca bu kopyadaki kişiler ve konuklar görebilir",
    "Federated" : "Birleşik",
    "Only synchronize to trusted servers" : "Yalnızca güvenilen sunucular ile eşitlensin",
    "Published" : "Yayınlanmış",
    "Synchronize to trusted servers and the global and public address book" : "Genel ve herkese açık adres defteri ile ve güvenilen sunucularla eşitlenir",
    "Verify" : "Doğrula",
    "Verifying …" : "Doğrulanıyor …",
    "Unable to change password" : "Parola değiştirilemedi",
    "Very weak password" : "Parola çok zayıf",
    "Weak password" : "Parola zayıf",
    "So-so password" : "Parola idare eder",
    "Good password" : "Parola iyi",
    "Strong password" : "Parola güçlü",
    "Groups" : "Gruplar",
    "Group list is empty" : "Grup listesi boş",
    "Unable to retrieve the group list" : "Grup listesi alınamadı",
    "{actor} added you to group {group}" : "{actor} sizi {group} grubuna ekledi",
    "You added {user} to group {group}" : "{user} kullanıcısını {group} grubuna eklediniz",
    "{actor} added {user} to group {group}" : "{actor} {user} kullanıcısını {group} grubuna ekledi",
    "An administrator added you to group {group}" : "Bir yönetici sizi {group} grubuna ekledi",
    "An administrator added {user} to group {group}" : "Bir yönetici {user} kullanıcısını {group} grubuna ekledi",
    "{actor} removed you from group {group}" : "{actor} sizi {group} grubundan çıkardı",
    "You removed {user} from group {group}" : "{user} kullanıcısını {group} grubundan çıkardınız",
    "{actor} removed {user} from group {group}" : "{actor} {user} kullanıcısını {group} grubundan çıkardı",
    "An administrator removed you from group {group}" : "Bir yönetici sizi {group} grubundan çıkardı",
    "An administrator removed {user} from group {group}" : "Bir yönetici {user} kullanıcısını {group} grubundan çıkardı",
    "Your <strong>group memberships</strong> were modified" : "<strong>Grup üyelikleriniz</strong> değiştirildiğinde",
    "{actor} changed your password" : "{actor} parolanızı değiştirdi",
    "You changed your password" : "Parolanızı değiştirdiniz",
    "Your password was reset by an administrator" : "Parolanız bir yönetici tarafından sıfırlandı",
    "Your password was reset" : "Parolanız sıfırlandı",
    "{actor} changed your email address" : "{actor} e-posta adresinizi değiştirdi",
    "You changed your email address" : "E-posta adresinizi değiştirdiniz",
    "Your email address was changed by an administrator" : "E-posta adresiniz bir yönetici tarafından değiştirildi",
    "You created an app password for a session named \"{token}\"" : "\"{token}\" adlı oturum için bir uygulama parolası oluşturdunuz",
    "An administrator created an app password for a session named \"{token}\"" : "Bir yönetici \"{token}\" adlı oturum için bir uygulama parolası oluşturdu",
    "You deleted app password \"{token}\"" : "\"{token}\" uygulama parolasını sildiniz",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "\"{token}\" olan uygulama parolasını \"{newToken}\" olarak yeniden adlandırdınız",
    "You granted filesystem access to app password \"{token}\"" : "\"{token}\" uygulama parolasına dosya sistemi erişim izni verdiniz",
    "You revoked filesystem access from app password \"{token}\"" : "\"{token}\" uygulama parolasından dosya sistemi erişim iznini kaldırdınız",
    "Security" : "Güvenlik",
    "You successfully logged in using two-factor authentication (%1$s)" : "İki adımlı doğrulama ile oturum açtınız (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "İki adımlı doğrulama ile oturum açma girişimi reddedildi (%1$s)",
    "Remote wipe was started on %1$s" : "Uzaktan silme işlemi %1$s zamanında başlatıldı",
    "Remote wipe has finished on %1$s" : "Uzaktan silme işlemi %1$s zamanında tamamlandı",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parolanız</strong> ya da <strong>e-posta adresiniz</strong> değiştirildiğinde",
    "Apps" : "Uygulamalar",
    "Could not remove app." : "Uygulama kaldırılamadı.",
    "Could not update app." : "Uygulama güncellenemedi.",
    "Wrong password" : "Parola yanlış",
    "Unable to change personal password" : "Kişisel parolanız değiştirilemedi",
    "Saved" : "Kaydedildi",
    "No user supplied" : "Kullanıcı belirtilmemiş",
    "Unable to change password. Password too long." : "Parola çok uzun olduğundan değiştirilemedi. ",
    "Authentication error" : "Kimlik doğrulama sorunu",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Lütfen bir yönetici kurtarma parolası yazın, yoksa tüm kullanıcı verileri kaybolur",
    "Wrong admin recovery password. Please check the password and try again." : "Yönetici kurtarma parolası yanlış. Lütfen parolayı denetleyip yeniden deneyin.",
    "Backend does not support password change, but the user's encryption key was updated." : "Yönetim bölümünden parola değişikliği yapılamaz, ancak kullanıcının şifreleme anahtarı güncellendi.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Uygulama mağazası ve birleşik bulut paylaşımı üzerinden uygulama kurma ve güncelleme",
    "Federated Cloud Sharing" : "Birleşik Bulut Paylaşımı",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL eski bir %1$s sürümü kullanıyor (%2$s). Lütfen işletim sisteminizi güncelleyin, yoksa %3$s gibi özellikler düzgün çalışmaz.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "https://nextcloud.com üzerine yapılan HTTPS isteği sırasında oluşan sorun nedeniyle cURL TLS sürümünün eski olup olmadığı belirlenemedi. Ayrıntılı bilgi almak için Nextcloud günlük dosyasına bakabilirsiniz.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modülü yüklenmemiş. Daha iyi başarım sağlamak için PHP kurulumunuza eklemeniz önerilir.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache devre dışı. Daha iyi başarım için PHP yapılandırmanızda <code>opcache.enable=1</code> seçeneğini ayarlamanız önerilir.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache, kod yorumlarını kaldıracak şekilde yapılandırılmış. OPcache etkinken, Nextcloud uygulamasının çalışması için <code>opcache.save_comments=1</code> ayarı yapılmalıdır.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud tarafından OPcache API' yazılımının kullanmasına izin verilmez. OPcache etkinleştirildiğinde, Nextcloud çekirdeği veya uygulama yükseltmeleri sırasında hataları önlemek için <code>opcache.restrict_api</code> ile tüm Nextcloud klasörlerini katmanız ya da OPcache API kısıtlamalarını devre dışı bırakmak için bu ayarı kaldırmanız önemle önerilir.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud tarafından OPcache API' yazılımının kullanmasına izin verilmez. Nextcloud çekirdeği veya uygulama yükseltmeleri sırasında hataları önlemek için <code>opcache.restrict_api</code> ile tüm Nextcloud klasörlerini katmanız ya da OPcache API kısıtlamalarını devre dışı bırakmak için bu ayarı kaldırmanız önemle önerilir.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Paylaşılan bellek temelli OPcache devre dışı bırakılmış. Başarımı iyileştirmek için PHP yapılandırmanızda <code>opcache.file_cache_only=0</code> seçeneğini ayarlamanız ve dosya ön belleğini yalnızca ikinci düzey ön bellek olarak kullanmanız önerilir.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "En fazla OPcache anahtar sayısına neredeyse erişildi. Tüm betik dosyalarının ön bellekte tutulabilmesini sağlamak için, PHP yapılandırmanıza <code>%s</code> üzerinde bir değerle <code>opcache.max_accelerated_files</code> uygulamanız önerilir.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache ara belleği neredeyse dolu. Tüm betik dosyalarının ön bellekte tutulabilmesini sağlamak için, PHP yapılandırmanıza <code>%s</code> üzerinde bir değerle <code>opcache.memory_consumption</code> uygulamanız önerilir.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache interned dizge ara belleği neredeyse dolu. Yinelenen dizgelerin etkin bir şekilde ön belleğe alınabilmesini sağlamak için, PHP yapılandırmanıza <code>%s</code> üzerinde bir değerle <code>opcache.interned_strings_buffer</code> uygulamanız önerilir.",
    "Administrator documentation" : "Yönetici belgeleri",
    "User documentation" : "Kullanıcı belgeleri",
    "Invalid SMTP password." : "SMTP parolası geçersiz.",
    "Email setting test" : "E-posta ayarları sınaması",
    "Well done, %s!" : "Tamamdır %s!",
    "If you received this email, the email configuration seems to be correct." : "Bu e-postayı aldıysanız e-posta ayarları doğru olarak yapılmıştır.",
    "Email could not be sent. Check your mail server log" : "E-posta gönderilemedi. E-posta sunucunuzun günlüklerine bakın",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posta gönderilirken bir sorun çıktı. Lütfen ayarlarınızı gözden geçirin. (Hata: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Sınama e-postaları göndermeden önce kullanıcı e-postanızı ayarlamalısınız. Bunun için %s bölümüne gidin.",
    "Users" : "Kullanıcılar",
    "Invalid user" : "Kullanıcı geçersiz",
    "Invalid mail address" : "E-posta adresi geçersiz",
    "Settings saved" : "Ayarlar kaydedildi",
    "Unable to change full name" : "Tam adınız değiştirilemedi",
    "Unable to change email address" : "E-posta adresi değiştirilemedi",
    "Unable to set invalid phone number" : "Telefon numarası geçersiz olduğundan ayarlanamadı",
    "Unable to set invalid website" : "Site geçersiz olduğundan ayarlanamadı",
    "Some account data was invalid" : "Bazı hesap bilgileri geçersiz",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Twitter hesabınızı doğrulamak için şu iletiyi Twitter üzerine gönderin (satır sonu olmadan gönderdiğinizden emin olun):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Sitenizi doğrulamak için şu içeriği sitenizin kök klasörüne '.well-known/CloudIdVerificationCode.txt' dosyası içine ekleyin (tüm içeriğin tek bir satır olarak eklendiğinden emin olun):",
    "%1$s changed your password on %2$s." : "%1$s, %2$s üzerindeki parolanızı değiştirdi.",
    "Your password on %s was changed." : "%s üzerindeki parolanız değiştirildi.",
    "Your password on %s was reset by an administrator." : "%s üzerindeki parolanız bir yönetici tarafından sıfırlandı.",
    "Your password on %s was reset." : "%s parolanız sıfırlandı.",
    "Password for %1$s changed on %2$s" : "%2$s üzerindeki %1$s parolası değiştirildi",
    "Password changed for %s" : "%s parolası değiştirildi",
    "If you did not request this, please contact an administrator." : "Bu işlemi siz başlatmadıysanız lütfen bir yönetici ile görüşün.",
    "Your email address on %s was changed." : "%s üzerindeki e-posta adresiniz değiştirildi.",
    "Your email address on %s was changed by an administrator." : "%s üzerindeki e-posta adresiniz bir yönetici tarafından değiştirildi.",
    "Email address for %1$s changed on %2$s" : "%2$s üzerindeki %1$s e-posta değiştirildi",
    "Email address changed for %s" : "%s e-posta adresi değiştirildi",
    "The new email address is %s" : "Yeni e-posta adresi: %s",
    "Your %s account was created" : "%s hesabınız oluşturuldu",
    "Welcome aboard" : "Panonuza hoş geldiniz",
    "Welcome aboard %s" : "%s panonuza hoş geldiniz",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s hesabınıza hoş geldiniz. Verilerinizi ekleyip koruyabilir ve paylaşabilirsiniz.",
    "Your username is: %s" : "Kullanıcı adınız: %s",
    "Set your password" : "Parolanızı ayarlayın",
    "Go to %s" : "%s sayfasına gidin",
    "Install Client" : "İstemciyi kurun",
    "Logged in user must be a subadmin" : "Oturum açmış kullanıcı bir alt yönetici olmalıdır",
    "Settings" : "Ayarlar",
    "Personal" : "Kişisel",
    "Administration" : "Yönetim",
    "Additional settings" : "Ek ayarlar",
    "Administration privileges" : "Yönetim yetkileri",
    "Groupware" : "Grup çalışması",
    "Overview" : "Özet",
    "Basic settings" : "Temel ayarlar",
    "Sharing" : "Paylaşım",
    "Availability" : "Uygunluk",
    "Calendar" : "Takvim",
    "Personal info" : "Kişisel bilgiler",
    "Mobile & desktop" : "Mobil ve masaüstü",
    "Email server" : "E-posta sunucusu",
    "Security & setup warnings" : "Güvenlik ve kurulum uyarıları",
    "Background jobs" : "Arka plan görevleri",
    "Create" : "Ekle",
    "Change" : "Değiştir",
    "Delete" : "Sil",
    "Reshare" : "Yeniden paylaş",
    "Unlimited" : "Sınırsız",
    "Verifying" : "Doğrulanıyor",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Kullanıcı tarafından içe aktarılmış SSL sertifikalarını denetleyen bir arka plan görevi bekliyor. Lütfen bir süre sonra yeniden denetleyin.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Kullanıcı tarafından içe aktarılmış ancak artık Nextcloud 21 ile kullanılmayan bazı SSL sertifikaları var. Bunlar, komut satırından \"occ security:certificates:import\" komutu ile içe aktarılabilir. Veri klasörü içindeki yollarını aşağıda görebilirsiniz.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP kullanıcıları ya da grupları için geçersiz UUID değerleri bulundu. Lütfen LDAP yapılandırmasının Uzman bölümündeki \"UUID algılaması değiştirilsin\" seçeneğini gözden geçirin ve bunları güncellemek için \"occ ldap:update-uuid\" kullanın.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Eski sunucu tarafı şifreleme biçimi etkinleştirilmiş. Bu seçeneği devre dışı bırakmanız önerilir.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB \"%s\" sürümü kullanılıyor. Nextcloud 21 ve üzerinde bu sürüm desteklenmiyor. MariaDB 10.2 ve üzerindeki bir sürüm kullanılmalıdır.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" sürümü kullanılıyor. Nextcloud 21 sürümünde bu sürüm desteklenmiyor. MySQL 8.0 ya da MariaDB 10.2 ve üzerindeki bir sürüm kullanılmalıdır.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL \"%s\" sürümü kullanılıyor. Nextcloud 21 sürümünde bu sürüm desteklenmiyor. PostgreSQL 9.6 ve üzerindeki bir sürüm kullanılmalıdır.",
    "Profile information" : "Profil bilgileri",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profil görseli, tam ad, e-posta adresi, telefon numarası, adres, site, Twitter, kuruluş, rol, başlık, özgeçmiş ve profilde etkinleştirilmiş diğer bilgiler",
    "Nextcloud settings" : "Nextcloud ayarları",
    "Here you can decide which group can access certain sections of the administration settings." : "Hangi yönetici ayarlarına hangi grubun erişebileceğini bu bölümden belirleyebilirsiniz.",
    "None" : "Yok",
    "Unable to modify setting" : "Ayar değiştirilemedi",
    "Two-Factor Authentication" : "İki adımlı doğrulama",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tüm kullanıcılar ve belirli gruplar için iki adımlı doğrulama kullanılır. İki adımlı doğrulama hizmeti sağlayıcısını yapılandırmayan kullanıcılar oturum açamaz.",
    "Enforce two-factor authentication" : "İki adımlı doğrulama dayatılsın",
    "Limit to groups" : "Sınırlanacak gruplar",
    "Enforcement of two-factor authentication can be set for certain groups only." : "İki adımlı doğrulama yalnızca belirli gruplar için sınırlanabilir.",
    "Two-factor authentication is enforced for all members of the following groups." : "Belirtilen grupların tüm üyeleri için iki adımlı doğrulama kullanımı zorunlu olur.",
    "Enforced groups" : "Uygulanacak gruplar",
    "Two-factor authentication is not enforced for members of the following groups." : "Belirtilen grupların tüm üyeleri için iki adımlı doğrulama kullanımı zorunlu olmaz.",
    "Excluded groups" : "Uygulanmayacak gruplar",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Uygulanan ya da uygulanmayan gruplar belirtildiğinde, bir kullanıcının iki adımlı doğrulama kullanıp kullanmayacağına şu şekilde karar verilir. Herhangi bir grup belirtilmemiş ise, uygulanmayan grupların üyeleri dışındaki tüm üyeler için iki adımlı doğrulama kullanılır. Belirtilmiş gruplar varsa, uygulanan bu grupların üyeleri için iki adımlı doğrulama kullanılır. Bir kullanıcının hem uygulanan hem de uygulanmayan gruplarda üyeliği varsa, uygulanan grupların önceliği vardır ve iki adımlı doğrulama kullanılır.",
    "Save changes" : "Değişiklikleri kaydet",
    "All" : "Tümü",
    "Limit app usage to groups" : "Uygulama kullanımı şu gruplarla sınırlansın",
    "No results" : "Herhangi bir sonuç bulunamadı",
    "Update to {version}" : "{version} sürümüne güncelle",
    "Remove" : "Kaldır",
    "Disable" : "Devre dışı bırak",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Bu uygulama için en düşük Nextcloud sürümü belirtilmemiş. Bu durum ileride sorun çıkarır.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Bu uygulama için en yüksek Nextcloud sürümü belirtilmemiş. Bu durum ileride sorun çıkarır.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aşağıdaki bağımlılıklar sağlanmadığından bu uygulama kurulamıyor:",
    "View in store" : "Mağazada görüntüle",
    "Visit website" : "Siteye bakın",
    "Report a bug" : "Hata bildirin",
    "Admin documentation" : "Yönetici belgeleri",
    "Developer documentation" : "Geliştirici belgeleri",
    "This app is supported via your current Nextcloud subscription." : "Bu uygulamanın desteği geçerli Nextcloud aboneliğiniz ile sağlanır.",
    "Supported" : "Destekleniyor",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Öne çıkarılmış uygulamalar topluluk tarafından geliştirilmiştir. Temel işlevleri yerine getirirler ve üretim ortamında kullanılabilirler.",
    "Featured" : "Öne çıkarılmış",
    "Update to {update}" : "{update} sürümüne güncelle",
    "All apps are up-to-date." : "Tüm uygulamalar güncel",
    "Results from other categories" : "Diğer kategorilerden sonuçlar",
    "No apps found for your version" : "Sürümünüze uygun bir uygulama bulunamadı",
    "Disable all" : "Tümünü devre dışı bırak",
    "Enable all" : "Tümünü etkinleştir",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n uygulama için güncelleme yayınlanmış","%n uygulama için güncelleme yayınlanmış"],
    "_Update_::_Update all_" : ["Güncelle","Tümünü güncelle"],
    "Marked for remote wipe" : "Uzaktan silme için işaretlendi",
    "Device settings" : "Aygıt ayarları",
    "Allow filesystem access" : "Dosya sistemine erişilebilsin",
    "Rename" : "Yeniden adlandır",
    "Revoke" : "Geri al",
    "Wipe device" : "Aygıtı sil",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Silme işlemi henüz başlamamış ise bu kodun geri çekilmesi aygıtınızın silinmesini engelleyebilir.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android için Google Chrome",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS uygulaması",
    "{productName} Android app" : "{productName} Android uygulaması",
    "{productName} Talk for iOS" : "{productName} iOS için Talk",
    "{productName} Talk for Android" : "{productName} Android için Talk",
    "Sync client - {os}" : "Eşitleme istemcisi - {os}",
    "This session" : "Bu oturum",
    "Device" : "Aygıt",
    "Last activity" : "Son işlem",
    "Devices & sessions" : "Aygıt ve oturumlar",
    "Web, desktop and mobile clients currently logged in to your account." : "Şu anda hesabınıza oturum açmış internet, masaüstü ve mobil istemcileri.",
    "Do you really want to wipe your data from this device?" : "Bu aygıt üzerindeki verilerinizi silmek istediğinize emin misiniz?",
    "Confirm wipe" : "Silmeyi onayla",
    "Error while creating device token" : "Aygıt kodu oluşturulurken sorun çıktı",
    "Error while updating device token scope" : "Aygıt kodu aralığı güncellenirken sorun çıktı",
    "Error while updating device token name" : "Aygıt kodu adı güncellenirken sorun çıktı",
    "Error while deleting the token" : "Kod silinirken sorun çıktı",
    "Error while wiping the device with the token" : "Aygıtın kod ile silinmesinde sorun çıktı",
    "App name" : "Uygulama adı",
    "Create new app password" : "Yeni uygulama parolası oluştur",
    "Use the credentials below to configure your app or device." : "Uygulama ya da aygıtınızı yapılandırmak için aşağıdaki kimlik doğrulama bilgileri kullanılır.",
    "For security reasons this password will only be shown once." : "Güvenlik nedenleriyle bu parola yalnızca bir kez görüntülenir.",
    "Username" : "Kullanıcı adı",
    "Password" : "Parola",
    "Done" : "Tamam",
    "Show QR code for mobile apps" : "Mobil uygulamalar için QR kodu görüntülensin",
    "Copied!" : "Kopyalandı!",
    "Copy" : "Kopyala",
    "Could not copy app password. Please copy it manually." : "Uygulama parolası kopyalanamadı. Lütfen el ile kopyalayın.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Sunucunun düzgün çalışması için arka plan görevlerinin doğru şekilde ayarlanması önemlidir. Cron ayarının kullanılması önerilir. Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Last job execution ran {time}. Something seems wrong." : "Son görev yürütülmesi: {time}. Yanlış bir şeyler var.",
    "Last job ran {relativeTime}." : "Son görev yürütülmesi: {relativeTime}.",
    "Background job did not run yet!" : "Arka plan görevi henüz yürütülmemiş!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Her sayfa yüklendiğinde bir görev yürütülür. Kullanım şekli: Tek kullanıcılı kopya.",
    "Webcron" : "İnternet zamanlanmış görevi",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php, HTTP üzerinden her 5 dakikada bir cron.php sayfasını çağıran bir internet zamanlanmış görevi hizmetinde kayıtlıdır. Kullanım şekli: Çok küçük kopya (kullanıma bağlı olarak 1–5 kullanıcı).",
    "Cron (Recommended)" : "Cron (önerilen)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Bunu çalıştıraiblmek için PHP POSIX eklentisi gereklidir. Ayrıntılı bilgi almak için {linkstart}PHP belgelerine{linkend} bakabilirsiniz.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "5 dakikada bir cron.php dosyasının çağrılması için sistem cron hizmeti kullanılır. Tüm kopyalar için önerilir.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php dosyası \"{user}\" sistem kullanıcısı tarafından yürütülmelidir.",
    "Unable to update background job mode" : "Arka plan görevi kipi güncellenemedi",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Bu seçenek etkinleştirildiğinde, profil yeni kullanıcılar için varsayılan olur.",
    "Enable" : "Etkinleştir",
    "Unable to update profile default setting" : "Profil varsayılan ayarı güncellenemedi",
    "Server-side encryption" : "Sunucu tarafı şifreleme",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sunucu tarafındaki şifreleme, sunucuya yüklenen dosyaların şifrelenebilmesini sağlar. Bu özellik genel başarımı düşürdüğünden yalnızca gerek varsa etkinleştirin.",
    "Enable server-side encryption" : "Sunucu tarafı şifreleme kullanılsın",
    "Please read carefully before activating server-side encryption:" : "Lütfen sunucu tarafında şifrelemeyi etkinleştirmeden önce dikkatlice okuyun:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Şifreleme etkinleştirildiğinde, etkinleştirme anından sonra sunucuya yüklenen tüm dosyalar şifrelenir. Şifreleme daha sonra devre dışı bırakılmak istenirse, etkin şifreleme modülünün bu özelliği desteklemesi ve tüm ön koşulların (örneğin kurtarma anahtarı oluşturulması) yerine getirilmesi gerekir.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Şifreleme tek başına sistemin güvenliğini garanti etmez. Lütfen şifreleme uygulamasının nasıl çalıştığı ve desteklenen kullanım şekilleri hakkında ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Be aware that encryption always increases the file size." : "Şifreleme işleminin dosya boyutlarını büyüteceğini unutmayın.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Verilerinizi düzenli yedekleyin ve şifreleme kullanıyorsanız şifreleme anahtarlarınızın da verilerinizle birlikte yedeklendiğinden emin olun.",
    "This is the final warning: Do you really want to enable encryption?" : "Son uyarı: Şifrelemeyi etkinleştirmek istiyor musunuz?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Herhangi bir şifrelenme modülü yüklenmemiş. Lütfen uygulama menüsünden bir şifreleme modülünü etkinleştirin.",
    "Select default encryption module:" : "Varsayılan şifreleme modülünü seçin:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine aktarmalısınız. Lütfen \"Varsayılan şifreleme modülü\"nü etkinleştirip {command} komutunu yürütün",
    "Unable to update server side encryption config" : "Sunucu tarafı şifreleme yapılandırması güncellenemedi",
    "Rename group" : "Grubu yeniden adlandır",
    "Remove group" : "Grubu sil",
    "You are about to remove the group {group}. The users will NOT be deleted." : "{group} grubunu silmek üzeresiniz. Kullanıcılar SİLİNMEYECEK.",
    "Please confirm the group removal " : "Grubu silme işlemini onaylayın",
    "Current password" : "Geçerli parola",
    "New password" : "Yeni parola",
    "Change password" : "Parola değiştir",
    "Your profile information" : "Profil bilgileriniz",
    "Your profile picture" : "Profil görseliniz",
    "Upload profile picture" : "Profil görseli yükle",
    "Choose profile picture from Files" : "Dosyalar uygulamasından profil görseli seçin",
    "Remove profile picture" : "Profil görselini kaldır",
    "The file must be a PNG or JPG" : "Dosya PNG ya da JPG biçiminde olmalıdır",
    "Picture provided by original account" : "Görsel özgün hesabınız tarafından sağlanıyor",
    "Cancel" : "İptal",
    "Set as profile picture" : "Profil görseli olarak ayarla",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Lütfen profil görselinizin her yerde güncellenmesinin 24 saat kadar sürebileceğini unutmayın.",
    "Choose your profile picture" : "Profil görselinizi seçin",
    "Please select a valid png or jpg file" : "Lütfen geçerli bir png ya da jpg dosyası seçin",
    "Error setting profile picture" : "Profil görseli ayarlanırken sorun çıktı",
    "Error cropping profile picture" : "Profil görseli kırpılırken sorun çıktı",
    "Error saving profile picture" : "Profil görseli kaydediliirken sorun çıktı",
    "Error removing profile picture" : "Profil görseli kaldırılırken sorun çıktı",
    "Your biography" : "Özgeçmişiniz",
    "Details" : "Ayrıntılar",
    "You are a member of the following groups:" : "Şu gruplara üyesiniz:",
    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong> kullanıyorsunuz",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "<strong>{usage}</strong> / <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>) kullanıyorsunuz",
    "Your full name" : "Tam adınız",
    "Email options" : "E-posta seçenekleri",
    "Primary email for password reset and notifications" : "Parola sıfırlama ve bildirimler için birincil e-posta adresi",
    "Remove primary email" : "Birincil e-posta adresini sil",
    "Delete email" : "E-posta adresini sil",
    "Unset as primary email" : "Birincil e-posta işaretini kaldır",
    "This address is not confirmed" : "Bu adres doğrulanmamış",
    "Set as primary email" : "Birincil e-posta olarak ayarla",
    "Your email address" : "E-posta adresiniz",
    "Additional email address {index}" : "{index}. ek e-posta adresi",
    "Unable to delete primary email address" : "Birincil e-posta adresi silinemedi",
    "Unable to update primary email address" : "Birincil e-posta adresi güncellenemedi",
    "Unable to add additional email address" : "Ek e-posta adresi eklenemedi",
    "Unable to update additional email address" : "Ek e-posta adresi güncellenemedi",
    "Unable to delete additional email address" : "Ek e-posta adresi silinemedi",
    "No email address set" : "E-posta adresi belirtilmemiş",
    "Additional emails" : "Ek e-posta adresleri",
    "Your handle" : "Kodunuz",
    "Your headline" : "Başlığınız",
    "Language" : "Dil",
    "Help translate" : "Çeviriye yardım edin",
    "Unable to update language" : "Dil güncellenemedi",
    "No language set" : "Herhangi bir dil ayarlanmamış",
    "Locale" : "Yerel Ayar",
    "Week starts on {firstDayOfWeek}" : "Hafta başlangıcı: {firstDayOfWeek}",
    "Unable to update locale" : "Yerel ayar güncellenemedi",
    "No locale set" : "Herhangi bir yerel ayar seçilmemiş",
    "Your location" : "Konumunuz",
    "Your organisation" : "Kuruluşunuz",
    "Your phone number" : "Telefon numaranız",
    "Edit your Profile visibility" : "Profilinizin görünürlüğü değiştirin",
    "Enable Profile" : "Profili etkinleştir",
    "Unable to update profile enabled state" : "Profilin etkinleştirilme durumu güncellenemedi",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Profilinizde daha kısıtlayıcı olan görünürlük veya kapsam ayarına uyulur - Örneğin, görünürlük \"Herkese görüntülensin\" ve kapsam \"Özel\" olarak ayarlanmışsa, \"Özel\" seçimine uyulur.",
    "Unable to update visibility of {displayId}" : "{displayId} görünürlüğü güncellenemedi",
    "Your role" : "Pozisyonunuz",
    "Your Twitter handle" : "Twitter adresiniz",
    "Your website" : "Sitenizin adresi",
    "No {property} set" : "Herhangi bir {property} ayarlanmamış",
    "Unable to update {property}" : "{property} güncellenemedi",
    "Change scope level of {property}, current scope is {scope}" : "{property} kapsam düzeyini değiştir. Geçerli kapsam: {scope}",
    "Unable to update federation scope of the primary {property}" : "Birincil {property} birleşik kapsamı güncellenemedi",
    "Unable to update federation scope of additional {property}" : "Ek {property} birleşik kapsamı güncellenemedi",
    "Add additional email" : "Ek e-posta adresi ekle",
    "Add" : "Ekle",
    "You do not have permissions to see the details of this user" : "Bu kullanıcının ayrıntılarını görüntüleme izniniz yok",
    "Add new password" : "Yeni parola ekle",
    "Add new email address" : "Yeni e-posta adresi ekle",
    "Add user to group" : "Gruba kullanıcı ekle",
    "Set user as admin for" : "Kullanıcıyı şurada yönetici yap",
    "Select user quota" : "Kullanıcı kotasını seçin",
    "Delete user" : "Kullanıcıyı sil",
    "Wipe all devices" : "Tüm aygıtları sil",
    "Disable user" : "Kullanıcıyı devre dışı bırak",
    "Enable user" : "Kullanıcıyı etkinleştir",
    "Resend welcome email" : "Karşılama e-postasını yeniden gönder",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Aygıt kaybedildiğinde ya da kuruluş ile çalışma sona erdirildiğinde, bu özellik {userid} ile ilişkili tüm aygıtlardaki Nextcloud verilerini silebilir. Bu özellik yalnızca aygıtların İnternet bağlantısı olduğunda kullanılabilir.",
    "Remote wipe of devices" : "Uzaktan aygıt temizleme",
    "Wipe {userid}'s devices" : "{userid} aygıtlarını temizle",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} için kişisel dosyalar ve uygulama verileri gibi tüm hesap bilgilerini tamamen siler",
    "Account deletion" : "Hesap silme",
    "Delete {userid}'s account" : "{userid} hesabını sil",
    "Welcome mail sent!" : "Karşılama e-postası gönderildi!",
    "Edit User" : "Kullanıcıyı düzenle",
    "Toggle user actions menu" : "Kullanıcı işlemleri menüsünü değiştir",
    "{size} used" : "{size} kullanılmış",
    "New user" : "Yeni kullanıcı",
    "Will be autogenerated" : "Otomatik olarak oluşturulacak",
    "Display name" : "Görüntülenecek ad",
    "Email" : "E-posta",
    "Default language" : "Varsayılan dil",
    "Add a new user" : "Kullanıcı ekle",
    "Group admin for" : "Şunun grup yöneticisi",
    "Quota" : "Kota",
    "User backend" : "Kullanıcı arka ucu",
    "Storage location" : "Depolama konumu",
    "Last login" : "Son oturum açma",
    "No users in here" : "Henüz herhangi bir kullanıcı eklenmemiş",
    "Default quota" : "Varsayılan kota",
    "Common languages" : "Sık kullanılan diller",
    "Other languages" : "Diğer diller",
    "Password change is disabled because the master key is disabled" : "Ana anahtar devre dışı bırakıldığından parola değişikliği devre dışı bırakıldı.",
    "Passwordless authentication requires a secure connection." : "Parolasız kimlik doğrulama özelliği güvenli bir bağlantı üzerinden kullanılabilir.",
    "Add WebAuthn device" : "WebAuthn aygıtı ekle",
    "Please authorize your WebAuthn device." : "Lütfen WebAuthn aygıtınızın kimliğini doğrulayın.",
    "Name your device" : "Aygıtınıza bir ad verin",
    "Adding your device …" : "Aygıtınız ekleniyor …",
    "Server error while trying to add WebAuthn device" : "WebAuthn aygıtı eklenirken sunucu sorunu çıktı",
    "Server error while trying to complete WebAuthn device registration" : "WebAuthn aygıtı kaydedilirken sunucu sorunu çıktı",
    "Unnamed device" : "Adsız aygıt",
    "Passwordless Authentication" : "Parolasız kimlik doğrulaması",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Hesabınız için FIDO2 standardına uygun parolasız kimlik doğrulamasını kurun.",
    "No devices configured." : "Herhangi bir aygıt yapılandırılmamış.",
    "The following devices are configured for your account:" : "Hesabınız için şu aygıtlar yapılandırılmış:",
    "Your browser does not support WebAuthn." : "Tarayıcınız WebAuthn desteklemiyor.",
    "Your apps" : "Uygulamalarınız",
    "{license}-licensed" : "{license}-lisanslı",
    "Changelog" : "Değişiklik günlüğü",
    "by {author}\n{license}" : "{author} tarafından\n{license}",
    "Enter group name" : "Grup adını yazın",
    "Add group" : "Grup ekle",
    "Active users" : "Etkin kullanıcılar",
    "Admins" : "Yöneticiler",
    "Disabled users" : "Devre dışı bırakılmış kullanıcılar",
    "Default quota:" : "Varsayılan kota:",
    "Select default quota" : "Varsayılan kota değerini seçin",
    "Show Languages" : "Dilleri görüntüle",
    "Show last login" : "Son oturum açma zamanı görüntülensin",
    "Show user backend" : "Kullanıcı arka ucu görüntülensin",
    "Show storage path" : "Depolama yolu görüntülensin",
    "Send email to new user" : "Yeni kullanıcıya e-posta gönderilsin",
    "Not saved" : "Kaydedilmedi",
    "Sending…" : "Gönderiliyor …",
    "Email sent" : "E-posta gönderildi",
    "Location" : "Konum",
    "Profile picture" : "Profil görseli",
    "About" : "Hakkında",
    "Full name" : "Tam ad",
    "Additional email" : "Ek e-posta",
    "Headline" : "Başlık",
    "Organisation" : "Kuruluş",
    "Phone number" : "Telefon numarası",
    "Role" : "Pozisyon",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (Mastodon gibi)",
    "Website" : "Site",
    "Profile visibility" : "Profil görünürlüğü",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Bu özellik, dosya paylaşımı ve takvim çağrıları gibi temel işlevler için gerekli olduğundan kullanılamıyor",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Hesabınızda birleşik kullanım devre dışı bırakılmış olduğundan kullanılamıyor. Herhangi bir sorunuz varsa sistem yöneticinizle görüşün.",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Kullanıcıya özel verilerin arama sunucusunda yayınlanmasına izin verilmediğinden kullanılamıyor. Herhangi bir sorunuz varsa sistem yöneticinizle görüşün.",
    "Active apps" : "Etkin uygulamalar",
    "Disabled apps" : "Devre dışı uygulamalar",
    "Updates" : "Güncellemeler",
    "App bundles" : "Uygulama Paketleri",
    "Featured apps" : "Öne çıkarılmış uygulamalar",
    "Show to everyone" : "Herkese görüntülensin",
    "Show to logged in users only" : "Yalnızca oturum açmış kullanıcılara görüntülensin",
    "Hide" : "Gizlensin",
    "Download and enable" : "İndir ve etkinleştir",
    "Enable untested app" : "Denenmemiş uygulamalar kullanılabilsin",
    "The app will be downloaded from the App Store" : "Uygulama uygulama mağazasından indirilecek",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Bu uygulamanın kullandığınız Nextcloud sürümü ile uyumluluğu denetlenmemiş. İşlemi sürdürerek uygulamayı kurabilirsiniz. Ancak uygulama beklendiği gibi çalışmayabilir.",
    "Never" : "Asla",
    "An error occurred during the request. Unable to proceed." : "İstek sırasında bir sorun çıktı. İşlem sürdürülemiyor.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Uygulama etkinleştirilmiş fakat güncellenmesi gerekiyor. 5 saniye içinde güncelleme sayfasına yönlendirileceksiniz.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Hata: Bu uygulama sunucuda kararsızlığa yol açtığından etkinleştirilemez",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ağınızdan çok fazla istekte bulunuldu. Bir süre sonra yeniden deneyin ya da bir sorun olduğunu düşünüyorsanız BT yöneticiniz ile görüşün.",
    "Documentation" : "Belgeler",
    "Forum" : "Forum",
    "Login" : "Oturum açın",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Belgeleri aç",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Bu sunucunun parola sıfırlama ve bildirim işlemleri için e-posta gönderebilecek şekilde ayarlanmış olması önemlidir.",
    "Send mode" : "Gönderim kipi",
    "Encryption" : "Şifreleme",
    "Sendmail mode" : "Sendmail kipi",
    "From address" : "Kimden adresi",
    "Server address" : "Sunucu adresi",
    "Port" : "Bağlantı noktası",
    "Authentication method" : "Kimlik doğrulama yöntemi",
    "Only applies when authentication is required" : "Yalnızca kimlik doğrulaması istendiğinde uygulanır",
    "Authentication required" : "Kimlik doğrulaması gerekli",
    "Credentials" : "Kimlik doğrulama bilgileri",
    "SMTP Username" : "SMTP kullanıcı adı",
    "SMTP Password" : "SMTP parolası",
    "Save" : "Kaydet",
    "Test and verify email settings" : "E-posta ayarlarını sınayın ve doğrulayın",
    "Send email" : "E-posta gönder",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Kopyanızın güvenli ve yüksek başarımla çalışması için ayarların doğru yapılmış olması önemlidir. Bunu sağlamak için bazı otomatik denetimler yapılır. Ayrıntılı bilgi almak için İpuçları bölümüne ve belgelere bakın.",
    "All checks passed." : "Tüm denetimlerden geçti.",
    "There are some errors regarding your setup." : "Kurulumunuz ile ilgili bazı sorunlar var.",
    "There are some warnings regarding your setup." : "Kurulumunuz ile ilgili bazı uyarılar var.",
    "Checking for system and security issues." : "Sistem ve güvenlik sorunları denetleniyor.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lütfen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">kurulum rehberlerini↗</a> yeniden gözden geçirin ve <a href=\"%2$s\">günlük</a> kayıtlarındaki hata ve uyarılara bakın.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Güvenlik sınamamızdan ↗</a> geçirerek Nextcloud güvenliğinizi denetleyin.",
    "Version" : "Sürüm",
    "You need to enable the File sharing App." : "Dosya paylaşımı uygulamasını etkinleştirmelisiniz.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Yönetici olarak paylaşma davranışı ile ilgili ince ayarları yapabilirsiniz. Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Allow apps to use the Share API" : "Uygulamalar Paylaşım API kullanabilsin",
    "Set default expiration date for shares" : "Paylaşımlar için varsayılan kullanma süresi sonu ayarlansın",
    "Expire after" : "Geçerlilik süresi sonu",
    "day(s)" : "gün",
    "Enforce expiration date" : "Son kullanma tarihi dayatılsın",
    "Set default expiration date for shares to other servers" : "Diğer sunuculara yapılan paylaşımlar için varsayılan kullanma süresi sonu ayarlansın",
    "Allow users to share via link and emails" : "Kullanıcılar bağlantı ve e-posta ile paylaşabilsin",
    "Allow public uploads" : "Herkes yükleyebilsin",
    "Always ask for a password" : "Her zaman parola sorulsun",
    "Enforce password protection" : "Parola koruması dayatılsın",
    "Exclude groups from password requirements:" : "Parola gereksinimlerine katılmayacak gruplar:",
    "Set default expiration date" : "Varsayılan son kullanma tarihi ayarlansın",
    "Exclude groups from creating link shares:" : "Şu gruplar bağlantı paylaşımı oluşturamasın:",
    "Allow resharing" : "Yeniden paylaşılabilsin",
    "Allow sharing with groups" : "Gruplar ile paylaşılabilsin",
    "Restrict users to only share with users in their groups" : "Kullanıcılar, yalnızca kendi gruplarındaki kullanıcılarla paylaşabilsin",
    "Exclude groups from sharing" : "Gruplar paylaşıma katılmasın",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu gruplar paylaşımları alabilir ancak başlatamaz.",
    "Allow username autocompletion in share dialog" : "Paylaşım penceresinde kullanıcı adı otomatik olarak tamamlanabilsin",
    "Allow username autocompletion to users within the same groups" : "Aynı gruplardaki kullanıcıların kullanıcı adları otomatik olarak tamamlanabilsin",
    "Allow username autocompletion to users based on phone number integration" : "Telefon numarası bütünleştirmesi eşleşmelerine göre kullanıcı adları otomatik olarak tamamlanabilsin",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"Aynı grup\" ve \"telefon numarası bütünleştirmesi\" etkinleştirilmiş ise. Kullanıcının görüntülenmesi için ikisinden birinde eşleşme olması yeterlidir.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tam ad ya da e-posta adresi yazılırken otomatik olarak tamamlanabilsin (aynı grupta olma ya da telefon defteri eşleşmesi yok sayılarak)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Herkese açık bağlantı yükleme sayfasında sorumluluk reddi bildirimi görüntülensin (yalnızca dosya listesi gizli iken görüntülenir)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Dosya listesi gizliyken herkese açık bağlantı yükleme sayfasında görüntülenecek sorumluluk reddi bildirimi metnini buraya yazabilirsiniz.",
    "Default share permissions" : "Varsayılan paylaşım izinleri",
    "Reasons to use Nextcloud in your organization" : "Kuruluşunuzda Nextcloud kullanma nedenleriniz",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud topluluğu tarafından geliştirilmiştir{linkclose}.  {githubopen}Kaynak kodu{linkclose} {licenseopen}AGPL{linkclose} koşulları altında lisanslanmıştır.",
    "Like our Facebook page" : "Facebook sayfamızı beğenin",
    "Follow us on Twitter" : "Bizi Twitter üzerinde izleyin",
    "Follow us on Mastodon" : "Bizi Mastodon üzerinde izleyin",
    "Check out our blog" : "Bloğumuza bakın",
    "Subscribe to our newsletter" : "Bültenimize abone olun",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Bu Nextcloud topluluk sürümü desteklenmiyor ve anlık bildirimler kullanılamıyor.",
    "Use a second factor besides your password to increase security for your account." : "Parolanızın yanında ikinci bir doğrulama kullanarak hesabınızın güvenliğini arttırabilirsiniz.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud bağlantısı kurmak için üçüncü taraf uygulamaları kullanıyorsanız, lütfen iki adımlı doğrulamayı etkinleştirmeden önce her biri için bir uygulama parolası oluşturduğunuzdan ve yapılandırdığınızdan emin olun.",
    "An error occurred while changing your language. Please reload the page and try again." : "Dil değiştirilirken bir sorun çıktı. Lütfen sayfayı yeniden yükleyerek yeniden deneyin.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Yerel ayarlarınız değiştirilirken bir sorun çıktı. Lütfen sayfayı yeniden yükleyerek yeniden deneyin.",
    "Select a profile picture" : "Bir profil fotoğrafı seçin",
    "Week starts on {fdow}" : "Hafta başlangıcı {fdow}",
    "You created app password \"{token}\"" : "\"{token}\" uygulama parolasını oluşturdunuz",
    "An administrator created app password \"{token}\"" : "Bir yönetici \"{token}\" uygulama parolasını oluşturdu",
    "Couldn't remove app." : "Uygulama kaldırılamadı.",
    "Couldn't update app." : "Uygulama güncellenemedi.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Yönetim bölümünden parola değişikliği yapılamaz, ancak kullanıcının şifreleme anahtarı güncellendi.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "https://nextcloud.com üzerine yapılan HTTPS isteği sırasında oluşan sorun nedeniyle cURL TLS sürümünün eski olup olmadığı belirlenemedi. Ayrıntılı bilgi almak için nextcloud günlük dosyasına bakabilirsiniz.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "En fazla OPcache anahtar sayısına neredeyse erişildi. Tüm betik dosyalarının ön bellekte tutulabilmesini sağlamak için, PHP yapılandırmanıza <code>%s</code> üzerinde bir değerle <code>opcache.max_accelerated_files</code> uygulamanız önerilir.",
    "Admin privileges" : "Yönetici yetkileri",
    "Unable to update biography" : "Özgeçmiş güncellenemedi",
    "Unable to update full name" : "Tam ad güncellenemedi",
    "No full name set" : "Tam ad belirtilmemiş",
    "Unable to update headline" : "Başlık güncellenemedi",
    "Unable to update organisation" : "Kuruluş güncellenemedi",
    "Unable to update role" : "Pozisyon güncellenemedi",
    "Change scope level of {accountProperty}" : "{accountProperty} kapsam düzeyini değiştir",
    "Unable to update federation scope of the primary {accountProperty}" : "Birincil {accountProperty} birleşik kapsamı güncellenemedi",
    "Unable to update federation scope of additional {accountProperty}" : "Ek {accountProperty} birleşik kapsamı güncellenemedi",
    "Migration in progress. Please wait until the migration is finished" : "Aktarılıyor. Lütfen işlem tamamlanana kadar bekleyin",
    "Migration started …" : "Aktarım başladı …",
    "Address" : "Adres",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "İstek sırasında bir sorun çıktı. İşlem sürdürülemiyor.",
    "Plain" : "Düz",
    "NT LAN Manager" : "NT ağ yöneticisi",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Lütfen sunucu tarafında şifrelemeyi etkinleştirmeden önce dikkatlice okuyun: ",
    "Enable encryption" : "Şifreleme kullanılsın",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine aktarmalısınız. Lütfen \"Varsayılan şifreleme modülü\"nü etkinleştirip 'occ encryption:migrate' komutunu yürütün",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine aktarmalısınız.",
    "Start migration" : "Aktarmayı başlat",
    "Last job execution ran %s. Something seems wrong." : "Son görev yürütülmesi: %s. Yanlış bir şeyler var.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Bazı görevler %s zamanından beri yürütülmemiş. Lütfen yürütme sıklığını arttırmayı düşünün.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Bazı görevler %s zamanından beri çalışmadı. Lütfen sistem zamanlanmış görevlerini (cron) kullanımayı düşünün.",
    "Last job ran %s." : "Son görev çalışması: %s.",
    "Background job didn’t run yet!" : "Arka plan görevi henüz yürütülmemiş!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Sunucunun düzgün çalışması için arka plan görevlerinin doğru şekilde ayarlanması önemlidir. \"Cron\" ayarının kullanılası önerilir. Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Pick background job setting" : "Arka plan görevi ayarlarını seçin",
    "Recommended" : "Önerilen",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php dosyası \"%s\" sistem kullanıcısı tarafından yürütülmelidir.",
    "Change privacy level of profile picture" : "Profil görselinin gizlilik düzeyini değiştir",
    "Upload new" : "Yeni yükle",
    "Select from Files" : "Dosyalardan seç",
    "Remove image" : "Görseli kaldır",
    "png or jpg, max. 20 MB" : "png ya da jpg, en fazla 20 MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Lütfen Avatarın her yerde güncellenmesinin 24 saat kadar sürebileceğini unutmayın.",
    "Choose as profile picture" : "Profil görseli olarak seç",
    "You are using <strong>%s</strong>" : "<strong>%s</strong> kullanıyorsunuz",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Kullandığınız: <strong>%1$s</strong> Kullanabileceğiniz: <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of phone number" : "Telefon numarasının gizlilik düzeyini değiştir",
    "Change privacy level of address" : "Adresin gizlilik düzeyini değiştir",
    "Your postal address" : "Posta adresiniz",
    "Change privacy level of website" : "Sitenin gizlilik düzeyini değiştir",
    "It can take up to 24 hours before the account is displayed as verified." : "Hesabın doğrulanması ve görüntülenmesi 24 saate kadar zaman alabilir.",
    "Link https://…" : "Bağlantı https://…",
    "Change privacy level of Twitter profile" : "Twitter profilinin gizlilik düzeyini değiştir",
    "Twitter handle @…" : "Twitter kodu @…",
    "Choose profile picture from files" : "Profil görselini dosyalardan seçin"
},
"nplurals=2; plural=(n > 1);");
